summaryrefslogtreecommitdiffstats
path: root/content/common/gin_java_bridge_messages.h
diff options
context:
space:
mode:
Diffstat (limited to 'content/common/gin_java_bridge_messages.h')
-rw-r--r--content/common/gin_java_bridge_messages.h11
1 files changed, 8 insertions, 3 deletions
diff --git a/content/common/gin_java_bridge_messages.h b/content/common/gin_java_bridge_messages.h
index f9525b1..cbce413 100644
--- a/content/common/gin_java_bridge_messages.h
+++ b/content/common/gin_java_bridge_messages.h
@@ -7,6 +7,7 @@
// Multiply-included message file, hence no include guard.
#include "base/basictypes.h"
+#include "content/common/android/gin_java_bridge_errors.h"
#include "content/common/content_export.h"
#include "ipc/ipc_message_macros.h"
@@ -16,6 +17,8 @@
// Messages for handling Java objects injected into JavaScript -----------------
+IPC_ENUM_TRAITS(content::GinJavaBridgeError)
+
// Sent from browser to renderer to add a Java object with the given name.
// Object IDs are generated on the browser side.
IPC_MESSAGE_ROUTED2(GinJavaBridgeMsg_AddNamedObject,
@@ -45,14 +48,16 @@ IPC_SYNC_MESSAGE_ROUTED2_1(GinJavaBridgeHostMsg_HasMethod,
// a container to work around immutability of base::Value.
// Empty result list indicates that an error has happened on the Java side
// (either bridge-induced error or an unhandled Java exception) and an exception
// must be thrown into JavaScript.
// Some special value types that are not supported by base::Value are encoded
// as BinaryValues via GinJavaBridgeValue.
-IPC_SYNC_MESSAGE_ROUTED3_1(GinJavaBridgeHostMsg_InvokeMethod,
+IPC_SYNC_MESSAGE_ROUTED3_2(GinJavaBridgeHostMsg_InvokeMethod,
int32 /* object_id */,
std::string /* method_name */,
base::ListValue /* arguments */,
- base::ListValue /* result */)
+ base::ListValue /* result */,
+ content::GinJavaBridgeError /* error_code */)
// Sent from renderer to browser in two cases:
//
@@ -45,14 +48,16 @@ IPC_SYNC_MESSAGE_ROUTED2_1(GinJavaBridgeHostMsg_HasMethod,
// Empty result list indicates that an error has happened on the Java side
// (either bridge-induced error or an unhandled Java exception) and an exception
-// must be thrown into JavaScript.
+// must be thrown into JavaScript. |error_code| indicates the cause of
+// the error.
// Some special value types that are not supported by base::Value are encoded
// as BinaryValues via GinJavaBridgeValue.